BoolVector2D

Struct BoolVector2D 

pub struct BoolVector2D {
    pub x: bool,
    pub y: bool,
}
A 2d vector of booleans, useful for component-wise logic operations.

Fields

x: booly: bool

Implementations

Source

impl BoolVector2D

pub fn all(self) -> bool

Returns true if all components are true and false otherwise.

pub fn any(self) -> bool

Returns true if any component are true and false otherwise.

pub fn none(self) -> bool

Returns true if all components are false and false otherwise. Negation of any().

pub fn and(self, other: Self) -> Self

Returns new vector with by-component AND operation applied.

pub fn or(self, other: Self) -> Self

Returns new vector with by-component OR operation applied.

pub fn not(self) -> Self

Returns new vector with results of negation operation on each component.

pub fn select_point<T, U>( self, a: Point2D<T, U>, b: Point2D<T, U>, ) -> Point2D<T, U>

Returns point, each component of which or from a, or from b depending on truly value of corresponding vector component. true selects value from a and false from b.

pub fn select_vector<T, U>( self, a: Vector2D<T, U>, b: Vector2D<T, U>, ) -> Vector2D<T, U>

Returns vector, each component of which or from a, or from b depending on truly value of corresponding vector component. true selects value from a and false from b.

pub fn select_size<T, U>(self, a: Size2D<T, U>, b: Size2D<T, U>) -> Size2D<T, U>

Returns size, each component of which or from a, or from b depending on truly value of corresponding vector component. true selects value from a and false from b.